/*
 * Copyright 2017 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package fr.gaellalire.vestige.core.resource;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.CodeSigner;
import java.security.cert.Certificate;

/**
 * @author Gael Lalire
 */
public interface VestigeResource {

    InputStream getInputStream() throws IOException;

    long getSize();

    String getName();

    URL getCodeSourceURL();

    /**
     * Returns the code signers for the Resource, or null if none. This method should be called after {@link #getInputStream()} is read to the end of the stream
     */
    CodeSigner[] getCodeSigners();

    long getModificationTime();

    Certificate[] getCertificates();

    VestigeResourceLocator getVestigeResourceLocator();

}
